//	@阿杰爱学单片机 2024/08/025
// 	不停电下载示例：USB-CDC方式，PC端发送指令，触发MCU复位并自动下载
//  使用STC-ISP软件，点击发送用户自定义命令并开始下载，
//	或点击下载按钮，即可自动下载，无需按住P3.2和OFF按键（第一次下载需要按P3.2和OFF）
//	实验开发板：STC32G12K128屠龙刀三.1 主频@24MHz

#include "COMM/stc.h"		//调用头文件
#include "COMM/usb.h"

#define MAIN_Fosc 24000000UL		//定义主频24MHz

void SYS_Init(void);						// STC32初始化设置
void MyUSB_Init(void);					//USB不断电下载配置初始化设置
void GPIO_Init(void);						//IO口初始化设置
void delay_ms(u16 ms);


//------USB调试及复位所需定义-----
char *USER_DEVICEDESC = NULL;
char *USER_PRODUCTDESC = NULL;
char *USER_STCISPCMD = "@STCISP#"; 	//设置自动复位到ISP区的用户接口命令

#define SEG P2
SEG_Tab[]={0xc0,0xf9,0xa4,0xb0,0x99,0x92,0x82,0xf8,0x80,0x90};
u8 Num;


void main(void)      //主函数(程序从这里执行)
{
	SYS_Init();					// STC32初始化
	MyUSB_Init();				//USB初始化
	GPIO_Init();				//IO口初始化
	while(1)
	{
		if( DeviceState != DEVSTATE_CONFIGURED ) 	//
			continue;
		if( bUsbOutReady )								
		{
			usb_OUT_done();
		}
		P00=1;
		SEG=SEG_Tab[Num++];
		delay_ms(500);
		
	}
}

void SYS_Init()
{
	EAXFR = 1; 									// 使能访问 XFR
	CKCON = 0x00; 							// 设置外部数据总线速度为最快
	WTST = 0x00;								// 设置程序代码等待参数，等待时间为0个时钟，CPU执行程序速度最快
}

void GPIO_Init(void)
{
	P2M0=0x00;				//P2设置为准双向口
	P2M1=0x00;
	P0M0=0x01;				//P0设置为推挽输出
	P0M1=0x00;
}

void MyUSB_Init(void)
{
	//------USB调试及复位所需代码-----
  P3M0 &= ~0x03;
  P3M1 |= 0x03;
	
  IRC48MCR = 0x80;					 //使能内部48M高速IRC
  while (!(IRC48MCR & 0x01));//等待时钟稳定
	
	//CDC下载需要用下面这两行,若使用HID下载请屏蔽//
	 USBCLK = 0x00;
	 USBCON = 0x90;
	
	usb_init();								 //usb初始化
	//--------------------------------
	EA = 1;							// 使能EA总中断
}

void delay_ms(u16 ms)
{
	u16 i;
	do
	{
		i=MAIN_Fosc/6000;
		while(--i);
	}
	while(--ms);
}

